#ifndef DATA_COMPRESSION_H
#define DATA_COMPRESSION_H TRUE

/*
**  compression.h
**
**  (C) Copyright 2001-2003 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

/*****************************************************************************
** Compression class.
*/

#define VER_COMPRESSION 1.0

/*** Compression flags ***/

#define CMF_PASSWORD      0x00000001 /* A password has been set on the object */
#define CMF_NEW           0x00000002 /* Force the creation of a new file archive */
#define CMF_CREATEFILE    0x00000004 /* Create a new archive only if the source file does not already exist */
#define CMF_READONLY      0x00000008 /* Do not open existing files using write access */
#define CMF_NOLINKS       0x00000010 /* Be ignorant of symbolic links (treat them as normal files/folders) */
#define CMF_APPLYSECURITY 0x00000020 /* When decompressing, apply individual file permissions if they are available in the compression file */

/*** This structure is used by the FileList field ***/

#define FIELDS_COMPRESSEDFILE struct CompressedFile *Next;  \
   struct CompressedFile *Prev;  \
   STRING Name; \
   STRING Comment; \
   ULONG  CompressedSize; \
   ULONG  OriginalSize; \
   LONG   Year; \
   UBYTE  Month; \
   UBYTE  Day; \
   UBYTE  Hour; \
   UBYTE  Minute;

struct CompressedFile {
   FIELDS_COMPRESSEDFILE
};

/*****************************************************************************
** Feedback structure.
*/

struct CompressionFeedback {
   LONG   FeedbackID;         /* Set to one of the FDB integers */
   LONG   Index;              /* Index of the current file */
   STRING Path;               /* Name of the current file/path in the archive */
   STRING Destination;        /* Destination file/path during decompression */
   LONG   OriginalSize;       /* Original size of the file */
   LONG   CompressedSize;     /* Compressed size of the file */
   FLOAT  Progress;           /* Progress indicator (0 - 100%) */
   WORD   Year;
   WORD   Month;
   WORD   Day;
   WORD   Hour;
   WORD   Minute;
   WORD   Second;
   UBYTE  Reserved[40];       /* Reserved in case of future expansion */
};

#define FDB_DecompressFile 1
#define FDB_CompressFile   2
#define FDB_RemoveFile     3

/*** Return codes available to the feedback routine ***/

#define CFR_Okay   1
#define CFR_Skip   2
#define CFR_Abort  3

/*****************************************************************************
** Methods
*/

#define MT_CompressBuffer   -1   /* Compress a memory buffer */
#define MT_CompressFile     -2   /* Add a file to the compression object (supports wildcards) */
#define MT_DecompressBuffer -3   /* Decompress a memory buffer */
#define MT_DecompressFile   -4   /* Extract a single file or files (supports wildcards, a single * extracts everything) */
#define MT_RemoveFile       -5   /* Delete a file from the compression object (supports wildcards) */

struct mtCompressBuffer {
   APTR Input;
   LONG InputSize;
   APTR Output;
   LONG OutputSize;
   LONG Result;
};

struct mtCompressFile {
   STRING Location;
   STRING Path;
};

struct mtDecompressBuffer {
   APTR Input;
   APTR Output;
   LONG OutputSize;
   LONG Result;
};

struct mtDecompressFile {
   STRING Path;
   STRING Destination;
   LONG Flags;
};

struct mtRemoveFile {
   STRING Path;
};

#endif /* DATA_COMPRESSION_H */

